@@ -16,7 +16,7 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use Carp qw(croak);
 
@@ -53,6 +53,7 @@ An instance of L<Debian::AptContents> to be used when locating to which package
 a required module belongs.
 
 =item dpkg_available
+
 An instance of L<DPKG::Parse::Available> to be used when checking whether
 the locally available package is the required version. For example:
 
@@ -348,12 +349,12 @@ sub find_debs_for_modules {
                         $have_pkg->satisfies($dep);
                     }
                     else {
-                        warn qq(Unable to obtain version information for $module. You may need to )
-                            .qq(install and run "dselect update");
+                        warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
+                            .qq(You may need to install and run "apt update");
                     }
                 } @pkgs;
                 unless ( @satisfied ) {
-                    print "$module is available locally as @available, but does not satisfy $version"
+                    print "$module is available locally as @available, but does not satisfy $version\n"
                         if $verbose;
                     push @missing, $module;
                 }
