@@ -25,7 +25,7 @@ require v5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use base qw( Class::Accessor Tie::IxHash );
 
@@ -176,10 +176,14 @@ Returns true if I<$field> contains a list of dependencies. By default returns tr
 
 =item Build_Depends_Indep
 
+=item Build_Depends_Arch
+
 =item Build_Conflicts
 
 =item Build_Conflicts_Indep
 
+=item Build_Conflicts_Arch
+
 =item Depends
 
 =item Conflicts
@@ -202,8 +206,9 @@ Returns true if I<$field> contains a list of dependencies. By default returns tr
 
 our %dependency_list = map(
     ( $_ => 1 ),
-    qw( Build-Depends Build-Depends-Indep Build-Conflicts Build-Conflicts-Indep
-    Depends Conflicts Enhances Replaces Breaks Pre-Depends Recommends Suggests ),
+    qw( Build-Depends Build-Depends-Indep Build-Depends-Arch Build-Conflicts
+        Build-Conflicts-Indep Build-Conflicts-Arch Depends Conflicts Enhances
+        Replaces Breaks Pre-Depends Recommends Suggests ),
 );
 
 sub is_dependency_list {
