@@ -61,6 +61,8 @@ replaced with underscores.
 
 =item Description
 
+=item Package_Type
+
 =back
 
 C<Depends>, C<Conflicts> C<Breaks>, C<Recommends>, C<Suggests>, C<Enhances>,
@@ -91,14 +93,14 @@ package Debian::Control::Stanza::Binary;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use base 'Debian::Control::Stanza';
 
 use constant fields => qw(
     Package Architecture Section Priority Essential Depends Recommends Suggests
-    Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using Multi_Arch
-    Description _short_description _long_description
+    Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using
+    Multi_Arch Package_Type Description _short_description _long_description
 );
 
 =head1 CONSTRUCTOR
