@@ -43,20 +43,32 @@ replaced with underscores.
 
 =item Build_Conflicts_Indep
 
+=item Build_Conflicts_Arch
+
 =item Build_Depends
 
 =item Build_Depends_Indep
 
+=item Build_Depends_Arch
+
 =item Standards_Version
 
 =item Vcs_Browser
 
+=item Vcs_Arch
+
 =item Vcs_Bzr
 
-=item Vcs_CVS
+=item Vcs_Cvs
+
+=item Vcs_Darcs
 
 =item Vcs_Git
 
+=item Vcs_Hg
+
+=item Vcs_Mtn
+
 =item Vcs_Svn
 
 =item Homepage
@@ -77,15 +89,16 @@ package Debian::Control::Stanza::Source;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use base qw(Debian::Control::Stanza);
 
 use constant fields => qw (
-    Source Section Priority Maintainer Uploaders DM_Upload_Allowed 
-    Build_Conflicts Build_Conflicts_Indep Build_Depends Build_Depends_Indep
-    Standards_Version Vcs_Browser Vcs_Bzr Vcs_CVS Vcs_Git Vcs_Svn Homepage
-    Testsuite Rules_Requires_Root
+    Source Section Priority Maintainer Uploaders DM_Upload_Allowed
+    Build_Conflicts Build_Conflicts_Indep Build_Conflicts_Arch Build_Depends
+    Build_Depends_Indep Build_Depends_Arch Standards_Version
+    Vcs_Browser Vcs_Arch Vcs_Bzr Vcs_Cvs Vcs_Darcs Vcs_Git Vcs_Hg Vcs_Mtn Vcs_Svn
+    Homepage Testsuite Rules_Requires_Root
 );
 
 =head1 CONSTRUCTOR
