@@ -3,7 +3,7 @@ package Debian::DpkgLists;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use Cwd;
 
@@ -38,8 +38,9 @@ sub _cat_lists
     my ( $class, $callback ) = @_;
     while ( defined( my $f = </var/lib/dpkg/info/*.list> ) ) {
         my $pkg = $f;
+        # e.g. /var/lib/dpkg/info/libdbi-perl:amd64.list
         $pkg =~ s{^/var/lib/dpkg/info/}{};
-        $pkg =~ s/\.list$//;
+        $pkg =~ s/(?::\w+)?\.list$//;
         open my $fh, '<', $f or die "open($f): $!\n";
         while ( defined( my $l = <$fh> ) ) {
             chomp $l;
