@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use feature 'switch';
 
@@ -46,7 +46,7 @@ use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
 
-use constant debstdversion => '4.2.1';
+use constant debstdversion => '4.3.0';
 
 our %DEFAULTS = (
 );
@@ -833,13 +833,13 @@ sub extract_docs {
                     )
                     if (
                         $File::Find::name !~ m{$toplevelreadme_re}i
-                    and /^\b(README|TODO|BUGS|NEWS|ANNOUNCE|CONTRIBUTING)\b/i
+                    and /^\b(README|TODO|BUGS|NEWS|ANNOUNCE|CONTRIBUTING|CODE_OF_CONDUCT)\b/i
                     and !/\.(pod|pm)$/
                     and ( !$self->cfg->exclude
                         or $File::Find::name !~ $self->cfg->exclude )
                     and !/\.svn-base$/
                     and $File::Find::name
-                    !~ m{debian/README\.(?:source|[Dd]ebian)}
+                    !~ m{debian/(README\.(?:source|[Dd]ebian)|NEWS)}
                     );
             },
         },
@@ -925,34 +925,22 @@ sub update_file_list( $ % ) {
         next unless @$new_content;
         # pkgname.foo file
         my $pkg_file = $self->debian_file("$pkgname.$file");
-        my %uniq_content;
-        my @existing_content;
+        my @content;
+        tie @content, 'Array::Unique';
 
         # if a package.foo exists read its values first
         if ( -r $pkg_file ) {
             my $fh                = $self->_file_r($pkg_file);
-            @existing_content = $fh->getlines;
-            chomp(@existing_content);
-
-            # make list of files for package.foo unique
-            $uniq_content{$_} = 1 for @existing_content;
+            @content = $fh->getlines;
+            chomp(@content);
         }
 
-        $uniq_content{$_} = 1 for @$new_content;
+        push @content, @$new_content;
+        @content = sort @content;
 
-        # write package.foo file with unique entries
+        # write package.foo file
         open F, '>', $pkg_file or die $!;
-        for ( @existing_content, @$new_content ) {
-
-            # we have the unique hash
-            # we delete from it each printed line
-            # so if a line is not in the hash, this means we have already
-            # printed it
-            next unless exists $uniq_content{$_};
-
-            delete $uniq_content{$_};
-            print F "$_\n";
-        }
+        print F "$_\n" for @content;
         close F;
     }
 }
@@ -1077,7 +1065,7 @@ sub create_copyright {
             " Licensed under the Apache License, Version 2.0 (the \"License\");\n"
             . " you may not use this file except in compliance with the License.\n"
             . " You may obtain a copy of the License at\n"
-            . "     http://www.apache.org/licenses/LICENSE-2.0\n"
+            . "     https://www.apache.org/licenses/LICENSE-2.0\n"
             . " Unless required by applicable law or agreed to in writing, software\n"
             . " distributed under the License is distributed on an \"AS IS\" BASIS,\n"
             . " WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n"
@@ -1449,7 +1437,7 @@ The following special cases are detected:
 =item Module::Build::Tiny
 
 if L<Module::Build::Tiny> is present in the build-dependencies, debhelper
-dependency is raised to 9.20140227~.
+dependency is raised to 9.20140227~ in case it was lower before.
 
 =item dh --with=quilt
 
@@ -1460,14 +1448,13 @@ C<dh --with=quilt> needs quilt.
 If F</usr/share/quilt/quilt.make> is included in F<debian/rules>, a
 build-dependency on C<quilt> is added.
 
-=item Module::Build
+=item dh --with=perl_dbi
 
-The proper build-dependency in this case is
+A build dependency on C<libdbi-perl> is added.
 
-    perl
+=item dh --with=perl_openssl
 
-The on perl without a version is set as Lenny has already 5.10 which
-includes first Module::Build.
+A build dependency on C<perl-openssl-defaults> is added.
 
 =back
 
@@ -1495,17 +1482,26 @@ sub discover_utility_deps {
     }
     $build_deps->add( Debian::Dependency->new( 'debhelper', $debhelper_version ) );
 
-    $self->explained_dependency( 'Module::Build::Tiny', $build_deps,
-        'debhelper (>= 9.20140227~)' )
-        if ( $build_deps->has('libmodule-build-tiny-perl') or
-            $build_deps_indep->has('libmodule-build-tiny-perl') );
+    $self->explained_dependency(
+        'Module::Build::Tiny',
+        $build_deps,
+        'debhelper (>= 9.20140227~)'
+    ) if ( $build_deps->has('libmodule-build-tiny-perl') or
+          $build_deps_indep->has('libmodule-build-tiny-perl') );
 
     for ( @{ $self->rules->lines } ) {
         $self->explained_dependency(
             'dh --with=quilt',
-            $build_deps, 'quilt',
+            $build_deps,
+            'quilt'
         ) if /dh\s+.*--with[= ]quilt/;
 
+        $self->explained_dependency(
+            'quilt.make',
+            $build_deps,
+            'quilt'
+        ) if m{^include /usr/share/quilt/quilt.make};
+
         $self->explained_dependency(
             'dh --with=bash-completion',
             $build_deps,
@@ -1518,9 +1514,11 @@ sub discover_utility_deps {
             'libdbi-perl'
         ) if (/dh\s+.*--with[= ]perl[-_]dbi/);
 
-        $self->explained_dependency( 'quilt.make', $build_deps, 'quilt' )
-            if m{^include /usr/share/quilt/quilt.make};
-
+        $self->explained_dependency(
+            'dh --with=perl_openssl',
+            $build_deps,
+            'perl-openssl-defaults'
+        ) if (/dh\s+.*--with[= ]perl[-_]openssl/);
     }
 
     # Ensure both libmodule-build{,tiny}-perl and perl are in B-D
