@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -84,11 +84,16 @@ sub execute {
 
     $tarball //= $self->guess_debian_tarball if $self->cfg->{vcs} eq 'git';
 
-    unless ( defined $self->cfg->version ) {
-        $self->pkgversion( $self->version . '-1' );
+    if ( defined $self->cfg->version ) {
+        $self->pkgversion( $self->cfg->version );
     }
     else {
-        $self->pkgversion( $self->cfg->version );
+        if ( defined $self->cfg->revision ) {
+            $self->pkgversion( $self->version . '-' . $self->cfg->revision );
+        }
+        else {
+            $self->pkgversion( $self->version . '-1' );
+        }
     }
 
     $self->fill_maintainer;
