@@ -3,7 +3,7 @@ package DhMakePerl::Config;
 use strict;
 use warnings;
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 =head1 NAME
 
@@ -35,7 +35,7 @@ my @OPTIONS = (
     'only|o=s@',
     'packagename|p=s', 'pkg-perl!',
     'recursive!',
-    'requiredeps',
+    'requiredeps',     'revision=s',
     'source-format=s', 'vcs=s',
     'verbose!',        'version=s',
 );
@@ -68,7 +68,7 @@ use constant DEFAULTS => {
     backups       => 1,
     data_dir      => '/usr/share/dh-make-perl',
     dbflags       => ( $> == 0 ? "" : "-rfakeroot" ),
-    dh            => 10,
+    dh            => 11,
     dist          => '',
     email         => '',
     exclude       => Dpkg::Source::Package->get_default_diff_ignore_regex(),
